# ai-models-fourcastnetv2

`ai-models-fourcastnetv2` is an [ai-models](https://github.com/ecmwf-lab/ai-models) plugin to run Nvidia's spherical harmonics tranformer.

<TERMS OF USE>

### Installation

Right now you have to clone this repository and

`pip install -e .`

as the spherical model by Nvidia isn't public yet.


---

Once the model is public, to install the package, run:

```bash
pip install ai-models-fourcastnetv2
```

This will install the package and its dependencies.
